@@ -382,10 +382,14 @@ __zzip_parse_root_directory(int fd,
 	{ d = (void*)(fd_map+fd_gap+offset); } /* fd_map+fd_gap==u_rootseek */
         else
         {
-            if (io->seeks(fd, u_rootseek+offset, SEEK_SET) < 0)
+            if (io->seeks(fd, u_rootseek+offset, SEEK_SET) < 0) {
+		free(hdr0);
                 return ZZIP_DIR_SEEK;
-            if (io->read(fd, &dirent, sizeof(dirent)) < __sizeof(dirent))
+	    }
+            if (io->read(fd, &dirent, sizeof(dirent)) < __sizeof(dirent)) {
+		free(hdr0);
                 return ZZIP_DIR_READ;
+	    }
             d = &dirent;
         }
 
@@ -465,7 +469,8 @@ __zzip_parse_root_directory(int fd,
     
 	if (hdr_return) 
 	    *hdr_return = hdr0;
-    } /* else zero (sane) entries */
+    } else free(hdr0); /* else zero (sane) entries */
+
     return (entries ?  ZZIP_CORRUPTED : 0);
 }
 
@@ -726,6 +731,7 @@ zzip_dir_read(ZZIP_DIR * dir, ZZIP_DIRENT * d )
     d->st_size = dir->hdr->d_usize;
     d->d_name  = dir->hdr->d_name;
     d->d_flags = dir->hdr->d_flags;
+    d->d_crc32 = (int) dir->hdr->d_crc32;
 
     if (! dir->hdr->d_reclen) 
     { dir->hdr = 0; }
